@@ -1,6 +1,6 @@
 ;;; emacspeak-auctex.el --- Speech enable AucTeX -- a powerful TeX/LaTeX authoring environment
-;;; $Id: emacspeak-auctex.el,v 23.505 2005/11/25 16:30:49 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-auctex.el 5315 2007-09-27 16:14:42Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; DescriptionEmacspeak extensions for auctex-mode
 ;;; Keywords:emacspeak, audio interface to emacs AUCTEX
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:49 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-09-27 09:14:42 -0700 (Thu, 27 Sep 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -46,100 +46,30 @@
 
 ;;}}}
 ;;{{{ voice locking:
+
 ;;; faces from AUCTeX 11
-(def-voice-font emacspeak-latex-italic-face voice-animate
-  'font-latex-italic-face
-  "Face used for italics."
-  :group 'emacspeak-auctex)
-
-(def-voice-font emacspeak-latex-bold-face voice-bolden
-  'font-latex-bold-face
-  "Face used for bold."
-
-  :group 'emacspeak-auctex)
-
-(def-voice-font emacspeak-latex-sedate-personality voice-smoothen
-  'font-latex-sedate-face                                          
-  "Personality used  on macro names."                              
-  :group 'emacspeak-auctex)                                        
-
-(def-voice-font  emacspeak-latex-doctex-documentation-personality
-  voice-monotone
-  'font-latex-doctex-documentation-face
-  "Personality used for documentation in doctex files."
-  :group 'emacspeak-auctex)
-
-(def-voice-font  emacspeak-latex-doctex-preprocessor-personality
-  voice-brighten-medium
-  'font-latex-doctex-preprocessor-face
-  "Personality used for preprocessor lines in   doctex files."
-  :group 'emacspeak-auctex)
-
-(def-voice-font  emacspeak-latex-math-personality
-  voice-brighten-extra
-  'font-latex-math-face
-  "Personality used for math mode."
-  :group 'emacspeak-auctex)
-
-(def-voice-font  emacspeak-latex-string-personality
-  voice-lighten-extra
-  'font-latex-string-face
-  "Personality used for strings."
-  :group 'emacspeak-auctex)
-
-(def-voice-font  emacspeak-latex-subscript-personality
-  voice-smoothen
-  'font-latex-subscript-face
-  "Personality used for subscript."
-  :group 'emacspeak-auctex)
-
-(def-voice-font  emacspeak-latex-superscript-personality
-  voice-brighten-extra
-  'font-latex-superscript-face
-  "Personality used for superscript."
-  :group 'emacspeak-auctex)
-
-(def-voice-font  emacspeak-latex-title-1-personality
-  voice-bolden-extra
-  'font-latex-title-1-face
-  "Personality used for titl11."
-  :group 'emacspeak-auctex)
-(def-voice-font  emacspeak-latex-title-2-personality
-  voice-bolden-medium
-  'font-latex-title-2-face
-  "Personality used for titl11."
-  :group 'emacspeak-auctex)
-
-(def-voice-font  emacspeak-latex-title-3-personality
-  voice-bolden
-  'font-latex-title-3-face
-  "Personality used for titl11."
-  :group 'emacspeak-auctex)
-(def-voice-font  emacspeak-latex-title-3-personality
-  voice-bolden
-  'font-latex-title-3-face
-  "Personality used for titl11."
-  :group 'emacspeak-auctex)
-(def-voice-font  emacspeak-latex-title-4-personality
-  voice-smoothen
-  'font-latex-title-4-face
-  "Personality used for titl11."
-  :group 'emacspeak-auctex)
-
-(def-voice-font  emacspeak-latex-dwarningverbatim-personality
-  voice-animate
-  'font-latex-warning-face
-  "Personality used for warnings."
-  :group 'emacspeak-auctex)
-
-(def-voice-font  emacspeak-latex-verbatim-personality
-  voice-monotone
-  'font-latex-verbatim-face
-  "Personality used for verbatim."
-  :group 'emacspeak-auctex)
+(voice-setup-add-map
+ '(
+   (font-latex-bold-face voice-bolden)
+   (font-latex-doctex-documentation-face voice-monotone-medium)
+   (font-latex-doctex-preprocessor-face voice-brighten-medium)
+   (font-latex-italic-face voice-animate)
+   (font-latex-math-face voice-brighten-extra)
+   (font-latex-sedate-face voice-smoothen)
+   (font-latex-string-face voice-lighten)
+   (font-latex-subscript-face voice-smoothen)
+   (font-latex-superscript-face voice-brighten)
+   (font-latex-title-1-face voice-bolden-extra)
+   (font-latex-title-2-face voice-bolden-medium)
+   (font-latex-title-3-face voice-bolden)
+   (font-latex-title-4-face voice-smoothen-extra)
+   (font-latex-verbatim-face voice-monotone)
+   (font-latex-warning-face voice-bolden-and-animate)
+   ))
 
 ;;}}}
 ;;{{{  Marking structured objects:
+
 (defadvice LaTeX-fill-paragraph (after emacspeak pre act  comp)
   "Provide auditory feedback."
   (when (interactive-p)
@@ -175,7 +105,6 @@ Provide auditory feedback after formatting region"
     (message "Reformatted region"))
    ((not (interactive-p)) ad-do-it))
   ad-return-value)
-    
 
 ;;}}}
 ;;{{{  delimiter matching:
@@ -196,21 +125,40 @@ Provide auditory feedback after formatting region"
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-read-previous-line)))
 
-(defadvice TeX-insert-dollar (after emacspeak pre act comp)
-  "Speak what you inserted"
-  (when (interactive-p)
-    (emacspeak-speak-this-char  (preceding-char ))))
+(defadvice TeX-insert-quote(around emacspeak pre act com)
+  "Speak quotes that were inserted."
+  (cond
+   ((interactive-p)
+    (let ((orig (point)))
+      ad-do-it
+      (emacspeak-speak-region orig (point))))
+   (t ad-do-it))
+  ad-return-value)
+(loop for f in
+      '(TeX-insert-dollar TeX-insert-backslash
+                          LaTeX-babel-insert-hyphen)
+      do
+      (eval
+       `(defadvice ,f (after emacspeak pre act comp)
+	  "Speak what you inserted"
+	  (when (interactive-p)
+	    (emacspeak-speak-this-char  (preceding-char ))))))
 
 ;;}}}
 ;;{{{  Inserting structures
 
+(defadvice TeX-newline (after emacspeak pre act comp)
+  "Provide auditory feedback to indicate indentation."
+  (when (interactive-p)
+    (emacspeak-speak-line)))
+
 (defadvice LaTeX-insert-item (after emacspeak pre act)
   "Provide auditory feedback. "
   (when (interactive-p)
     (emacspeak-speak-line )))
 
 (defadvice LaTeX-environment (after emacspeak pre act)
-  "Provide auditory feedback, by speaking 
+  "Provide auditory feedback, by speaking
 the opening line of the newly inserted environment. "
   (when (interactive-p)
     (emacspeak-auditory-icon 'open-object)
@@ -250,7 +198,6 @@ the opening line of the newly inserted environment. "
     (emacspeak-auditory-icon 'select-object)))
 
 ;;}}}
-
 ;;{{{  Debugging tex
 
 (defadvice TeX-next-error (after emacspeak pre act)
@@ -267,19 +214,20 @@ the opening line of the newly inserted environment. "
 (add-hook  'LaTeX-mode-hook
            (function
             (lambda ()
-	      (declare (special imenu-generic-expression
-				imenu-create-index-function))
-	      (require 'imenu)
-	      (setq imenu-create-index-function 'imenu-default-create-index-function)
-	      (setq imenu-generic-expression
-		    '(
-		      (nil
-		       "^ *\\\\\\(sub\\)*section{\\([^}]+\\)"
-		       2))))))
+              (declare (special imenu-generic-expression
+                                imenu-create-index-function))
+              (require 'imenu)
+              (setq imenu-create-index-function 'imenu-default-create-index-function)
+              (setq imenu-generic-expression
+                    '(
+                      (nil
+                       "^ *\\\\\\(sub\\)*section{\\([^}]+\\)"
+                       2))))))
               
 
 ;;}}}
 ;;{{{ advice font changes 
+
 (defadvice TeX-font (around emacspeak pre act comp)
   "Speak the font we inserted"
   (cond 
@@ -288,7 +236,7 @@ the opening line of the newly inserted environment. "
       ad-do-it
       (if (ad-get-arg 0)
           (emacspeak-speak-line)
-	(emacspeak-speak-region orig (point)))))
+        (emacspeak-speak-region orig (point)))))
    (t ad-do-it))
   ad-return-value)
 
