@@ -1,6 +1,6 @@
 ;;; emacspeak-buff-menu.el --- Speech enable Buffer Menu Mode -- used to manage buffers
-;;; $Id: emacspeak-buff-menu.el,v 23.505 2005/11/25 16:30:49 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-buff-menu.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to buff-menu
 ;;; Keywords: Emacspeak, Speak, Spoken Output, buff-menu
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:49 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2004, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -51,11 +51,10 @@
 
 ;;}}}
 ;;{{{ voice personalities
-
-(def-voice-font  emacspeak-buffer-menu-buffer-face
-  voice-bolden
-  'Buffer-menu-buffer-face
-  "Personality for highlighting buffer name in buffer-menu.")
+(voice-setup-add-map
+ '(
+   (Buffer-menu-buffer voice-bolden)
+   ))
 
 ;;}}}
 ;;{{{  list buffers 
@@ -67,8 +66,8 @@
    ((eq major-mode 'Buffer-menu-mode)
     (let*((buffer (Buffer-menu-buffer t)))
       (if (get-buffer buffer)
-	  (dtk-speak (buffer-name  buffer))
-	(error "No valid buffer on this line"))))
+          (dtk-speak (buffer-name  buffer))
+        (error "No valid buffer on this line"))))
    (t (error "This command can be used only in buffer menus"))))
 
 (defun emacspeak-list-buffers-speak-buffer-line ()
@@ -112,10 +111,10 @@
                     (if (or file this-buffer-directory)
                         (format "visiting %s"
                                 (or file this-buffer-directory))
-		      "")
+                      "")
                     this-buffer-size))))
        (t(emacspeak-auditory-icon 'error)
-	 (emacspeak-speak-line)))))
+         (emacspeak-speak-line)))))
    (t (error "This command can be used only in buffer menus"))))
 
 (defun emacspeak-list-buffers-next-line (count)
