@@ -1,23 +1,23 @@
-;;; emacspeak-c.el --- Speech enable CC-mode and friends -- supports C, C++, Java 
-;;; $Id: emacspeak-c.el,v 23.505 2005/11/25 16:30:49 raman Exp $
-;;; $Author: raman $ 
+;;; emacspeak-c.el --- Speech enable CC-mode and friends -- supports C, C++, Java
+;;; $Id: emacspeak-c.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; DescriptionEmacspeak extensions for C and C++ mode
 ;;; Keywords:emacspeak, audio interface to emacs C, C++
-;;{{{  LCD Archive entry: 
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:49 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4637 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved. 
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -38,23 +38,20 @@
 ;;}}}
 ;;{{{ Introduction:
 
+;;; Commentary:
+
 ;;; Make some of C and C++ mode more emacspeak friendly
-;;; Works with both boring c-mode 
+;;; Works with both boring c-mode
 ;;; and the excellent cc-mode
 
 ;;}}}
 ;;{{{  Required modules
+
+;;; Code:
+
 (require 'emacspeak-preamble)
 (require 'cc-mode)
 
-;;}}}
-;;{{{  emacs 19.30
-
-;;; things got renamed in 19.30.
-
-(when  (string-lessp emacs-version "19.29")
-  (defalias 'c-guess-basic-syntax 'c-guess-basic-semantics))
-
 ;;}}}
 ;;{{{ advice electric deletion
 
@@ -91,7 +88,7 @@
 (defadvice c-electric-semi&comma (after emacspeak pre act )
   "Speak the line when a statement is completed."
   (when (interactive-p)
-    (cond 
+    (cond
      ((= last-input-char ?,) (dtk-speak " comma "))
      (t (emacspeak-speak-line )))))
 
@@ -152,9 +149,9 @@
     (dtk-tone 500 30)))
 
 ;;}}}
-;;{{{  Moving across logical chunks 
+;;{{{  Moving across logical chunks
 
-;;; CPP directives: 
+;;; CPP directives:
 
 (defadvice c-up-conditional (after emacspeak pre act )
   "Speak the line moved to."
@@ -174,7 +171,7 @@
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line )))
 
-;;; Statements 
+;;; Statements
 
 (defadvice c-beginning-of-statement (after emacspeak pre act )
   "Speak the line moved to."
@@ -188,14 +185,11 @@
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line )))
 
-(defadvice mark-c-function (after emacspeak pre act )
+(defadvice c-mark-function (after emacspeak pre act )
   "Provide spoken and auditory feedback."
   (when (interactive-p)
-    (let ((dtk-stop-immediately nil))
-      (emacspeak-auditory-icon 'mark-object)
-      (dtk-speak "Marked function containing %s lines "
-		 (count-lines (point) (mark)))
-      (emacspeak-speak-line ))))
+    (emacspeak-auditory-icon 'mark-object)
+    (emacspeak-speak-line)))
 
 ;;}}}
 
@@ -222,7 +216,7 @@
   (when (interactive-p)
     (dtk-speak "colon colon")))
 
-;;}}} 
+;;}}}
 ;;{{{  Some more navigation functions I define:
 
 (defun c-previous-statement (count)
@@ -235,16 +229,14 @@
     (cond
      ((or (assq 'c semantics )
           (assq 'comment-intro semantics ))
-      (while 
+      (while
           (and (or (assq 'c semantics )
                    (assq 'comment-intro semantics ))
                (not (eobp ))
                (= 0 (forward-line -1)))
         (setq semantics (c-guess-basic-syntax )))
       (skip-syntax-backward " ")
-      (dtk-speak "Skipping comment")
-      (and (sit-for 2)
-           (emacspeak-speak-line )))
+      (emacspeak-speak-line ))
      (t (setq count (or count 1))
         (c-beginning-of-statement   count )
         (and (save-match-data (looking-at "{"))
@@ -267,16 +259,14 @@ this level")
     (cond
      ((or (assq 'c semantics )
           (assq 'comment-intro semantics ))
-      (while 
+      (while
           (and (or (assq 'c semantics )
                    (assq 'comment-intro semantics ))
                (not (eobp ))
                (= 0 (forward-line 1)))
         (setq semantics (c-guess-basic-syntax )))
       (skip-syntax-forward " ")
-      (dtk-speak "Skipping  comment")
-      (and (sit-for 2)
-           (emacspeak-speak-line )))
+      (emacspeak-speak-line ))
      (t (setq count (or count 1))
         (c-end-of-statement(1+  count ))
         (c-beginning-of-statement  1 )
@@ -291,10 +281,10 @@ level")
           (emacspeak-speak-line))))))
 
 ;;}}}
-;;{{{  C semantics 
+;;{{{  C semantics
 
-(defvar emacspeak-c-syntactic-table 
-  (list 
+(defvar emacspeak-c-syntactic-table
+  (list
    '(string                 . "  inside multi-line string")
    '( c                      . "  inside a multi-line C
 style block comment")
@@ -306,7 +296,7 @@ style block comment")
    '( class-close            . "  brace that closes a class definition")
    '( inline-open            . "  brace that opens an in-class inline method")
    '( inline-close           . "  brace that closes an in-class inline method")
-   '( func-decl-cont         . "  the region between a 
+   '( func-decl-cont         . "  the region between a
 function definition's argument list and the function opening brace")
    '( knr-argdecl-intro      . "  first line of a K&R C argument declaration")
    '( knr-argdecl            . "  subsequent lines in a K&R
@@ -370,19 +360,19 @@ and their meanings. ")
                             (c-guess-basic-syntax )))
          (description ""))
     (setq description
-          (mapconcat 
-           (function (lambda (sem) 
+          (mapconcat
+           (function (lambda (sem)
                        (cdr (assq  sem emacspeak-c-syntactic-table ))))
-           semantics 
+           semantics
            " "))
-    (condition-case nil 
+    (condition-case nil
         (cond
          ((or (memq 'block-close semantics )
               (memq 'defun-close semantics )
               (memq 'class-close semantics )
               (memq 'inline-close semantics )
               (memq 'brace-list-close semantics ))
-          ;; append the line 
+          ;; append the line
           (setq description
                 (concat description
                         ;; that begins this block
@@ -414,12 +404,17 @@ and their meanings. ")
     (emacspeak-auditory-icon 'fill-object)
     (message "Indented function")))
 
+(defadvice c-indent-command (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (interactive-p)
+    (emacspeak-speak-line )))
+
 ;;}}}
 ;;{{{ Additional keybindings:
 
 (declaim (special c-mode-map
                   c-mode-base-map))
-(add-hook 'c-mode-common-hook 
+(add-hook 'c-mode-common-hook
           (function (lambda ()
                       (declare (special c-mode-map
                                         c-mode-base-map))
@@ -441,13 +436,21 @@ and their meanings. ")
                       (or dtk-allcaps-beep
                           (dtk-toggle-allcaps-beep)))))
 
+;;}}}
+;;{{{ personalities
+
+(voice-setup-add-map
+ '(
+   (c-nonbreakable-space-face voice-brighten)
+   ))
+
 ;;}}}
 (provide  'emacspeak-c)
-;;{{{  emacs local variables 
+;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
 ;;; byte-compile-dynamic: t
-;;; end: 
+;;; end:
 
 ;;}}}
