@@ -1,6 +1,6 @@
 ;;; emacspeak-entertain.el --- Speech enable misc games
-;;; $Id: emacspeak-entertain.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-entertain.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to diversions
 ;;; Keywords: Emacspeak, Speak, Spoken Output, games
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2004, T. V. Raman
+;;; Copyright (c) 1995 -- 2007, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -63,13 +63,13 @@
 
 ;;}}}
 ;;{{{ mpuz
-
-(def-voice-font emacspeak-mpuz-trivial-personality voice-monotone  'mpuz-trivial-face "")
-(def-voice-font emacspeak-mpuz-unsolved-personality voice-bolden  'mpuz-unsolved-face "")
-(def-voice-font emacspeak-mpuz-unsolved-personality voice-lighten  'mpuz-unsolved-face "")
-(def-voice-font emacspeak-mpuz-solved-personality voice-animate
-  'mpuz-solved-face "")
-
+(voice-setup-add-map
+ '(
+   (mpuz-trivial-face voice-monotone)
+   (mpuz-unsolved-face voice-bolden)
+   (mpuz-unsolved-face voice-lighten)
+   (mpuz-solved-face voice-animate)
+   ))
 ;;}}}
 ;;{{{ dunnet 
 
@@ -120,8 +120,8 @@
           (aset  string  i
                  (aref hm-current-guess-string (* i 2 ))))
     (message  "%s:  %s "
-	      (length string)
-	      (downcase string))))
+              (length string)
+              (downcase string))))
 
 (defadvice hangman (after emacseak pre act comp)
   "Speech enable hangman."
