@@ -1,6 +1,6 @@
 ;;; emacspeak-erc.el --- speech-enable erc irc client
-;;; $Id: emacspeak-erc.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-erc.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for speech-enabling erc.el
 ;;; Keywords: Emacspeak, erc
 ;;{{{  LCD Archive entry:
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ |
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4502 $ |
 ;;; Location undetermined
 ;;;
 
@@ -68,60 +68,23 @@
   "Set to T if you dont want to see notification  messages from the
 server."
   :type 'boolean
-  :group 'eamcspeak-erc)
+  :group 'emacspeak-erc)
 
-(def-voice-font emacspeak-erc-direct-msg-personality
-  voice-animate
-  'erc-direct-msg-face
-  "Personality for direct messages.")
-
-(def-voice-font  emacspeak-erc-input-personality 
-  voice-smoothen
-  'erc-input-face
-  "personality for input.")
-
-(def-voice-font emacspeak-erc-bold-personality
-  voice-bolden 'erc-bold-face
-  "Bold personality for ERC.")
-
-(def-voice-font emacspeak-erc-inverse-personality
-  voice-lighten-extra  'erc-inverse-face
-  "Inverse highlight in ERC.")
-
-(def-voice-font emacsepak-erc-underline voice-brighten-medium
-  'erc-underline-face
-  "Underline in ERC.")
-
-(def-voice-font emacspeak-erc-prompt-personality voice-bolden
-  'erc-prompt-face
-  "Personality for prompts.")
-
-(def-voice-font emacspeak-erc-notice-personality
-  'inaudible
-  'erc-notice-face
-  "Personality for notices.")
-
-(def-voice-font emacspeak-erc-action-personality
-  voice-monotone
-  'erc-action-face
-  "Personality for actions.")
-
-(def-voice-font emacspeak-erc-error-face
-  voice-bolden-and-animate 'erc-error-face
-  "Error personality for ERC.")
-
-(def-voice-font emacspeak-erc-dangerous-host-personality 
-  voice-brighten-extra 'erc-dangerous-host-face
-  "Personality for dangerous hosts.")
-
-      
-(def-voice-font emacspeak-erc-pal-personality 
-  voice-animate-extra 'erc-pal-face
-  "Personality for pals.")
-    
-(def-voice-font emacspeak-erc-keyword-personality 
-  voice-animate 'erc-keyword-face
-  "Personality for keywords.")
+(voice-setup-add-map
+ '(
+   (erc-direct-msg-face voice-animate)
+   (erc-input-face voice-smoothen)
+   (erc-bold-face voice-bolden)
+   (erc-inverse-face voice-lighten-extra)
+   (erc-underline-face voice-brighten-medium)
+   (erc-prompt-face voice-bolden)
+   (erc-notice-face (quote inaudible))
+   (erc-action-face voice-monotone)
+   (erc-error-face voice-bolden-and-animate)
+   (erc-dangerous-host-face voice-brighten-extra)
+   (erc-pal-face voice-animate-extra)
+   (erc-keyword-face voice-animate)
+   ))
 
 ;;}}}
 ;;{{{  helpers
@@ -187,12 +150,12 @@ spoken.")
      (let ((start (point)))
        (search-backward  "<" (point-min) t)
        (when (not (= start (point)))
-	 (setq start (point))
-	 (search-forward " ")
-	 (buffer-substring start (1- (point))))))))
+         (setq start (point))
+         (search-forward " ")
+         (buffer-substring start (1- (point))))))))
      
 (defun emacspeak-erc-add-name-to-monitor (name &optional
-					       quiten-pronunciation)
+                                               quiten-pronunciation)
   "Add people to moniter in this room.
 Optional interactive prefix  arg defines a pronunciation that
   silences speaking of this perso's name."
@@ -281,7 +244,7 @@ set the current local value to the result.")
     (save-excursion
       (set-buffer buffer)
       (when (and emacspeak-erc-room-monitor
-		 emacspeak-erc-monitor-my-messages)
+                 emacspeak-erc-monitor-my-messages)
         (let ((emacspeak-speak-messages nil)
               (msg (emacspeak-erc-compute-message (ad-get-arg 0)
                                                   buffer)))
@@ -289,7 +252,7 @@ set the current local value to the result.")
             (emacspeak-auditory-icon 'progress)
             (message msg)
             (tts-with-punctuations dtk-punctuation-mode
-				   (dtk-speak  msg))))))))
+                                   (dtk-speak  msg))))))))
 
 (defadvice erc-display-line-1  (after emacspeak pre act comp)
   "Speech-enable ERC."
@@ -301,7 +264,7 @@ set the current local value to the result.")
     (save-excursion
       (set-buffer buffer)
       (when (and emacspeak-erc-room-monitor
-		 emacspeak-erc-monitor-my-messages)
+                 emacspeak-erc-monitor-my-messages)
         (let ((emacspeak-speak-messages nil)
               (msg (emacspeak-erc-compute-message (ad-get-arg 0)
                                                   buffer)))
@@ -309,11 +272,11 @@ set the current local value to the result.")
             (emacspeak-auditory-icon 'progress)
             (message msg)
             (tts-with-punctuations dtk-punctuation-mode
-				   (dtk-speak  msg))))))))
+                                   (dtk-speak  msg))))))))
 
 (ems-generate-switcher 'emacspeak-erc-toggle-room-monitor
-		       'emacspeak-erc-room-monitor
-		       "Toggle state of ERC room monitor.
+                       'emacspeak-erc-room-monitor
+                       "Toggle state of ERC room monitor.
 Interactive 
 PREFIX arg means toggle the global default value, and then
 set the current local value to the result.")
