@@ -1,23 +1,23 @@
 ;;; emacspeak-gud.el --- Speech enable Emacs' debugger interface --covers GDB, JDB, and PerlDB
-;;; $Id: emacspeak-gud.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
-;;; DescriptionEmacspeak extensions for gud interaction 
-;;; Keywords:emacspeak, audio interface to emacs debuggers 
-;;{{{  LCD Archive entry: 
+;;; $Id: emacspeak-gud.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
+;;; DescriptionEmacspeak extensions for gud interaction
+;;; Keywords:emacspeak, audio interface to emacs debuggers
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
-;;; Copyright (c) 1995 by T. V. Raman 
-;;; All Rights Reserved. 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 by T. V. Raman
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -39,7 +39,7 @@
 
 ;;{{{  Introduction:
 
-;;; Provide additional advice to ease debugger interaction with gud 
+;;; Provide additional advice to ease debugger interaction with gud
 
 ;;}}}
 ;;{{{ requires
@@ -50,7 +50,8 @@
 
 (defadvice gud-display-line (after emacspeak pre act )
   "Speak the error line"
-  (let ((marker overlay-arrow-position ))
+  (declare (special gud-overlay-arrow-position))
+  (let ((marker gud-overlay-arrow-position ))
     (emacspeak-auditory-icon 'large-movement)
     (and marker
          (marker-buffer marker )
@@ -60,16 +61,37 @@
            (goto-char (marker-position marker ))
            (emacspeak-speak-line )))))
 
+(loop for f in
+      '(
+        gud-break
+        gud-tbreak
+        gud-remove
+        gud-step
+        gud-stepi
+        gud-next
+        gud-nexti
+        gud-cont
+        gud-finish
+        gud-jump
+        )
+      do
+      (eval
+       `(defadvice ,f (around emacspeak pre act comp)
+          "Silence minibuffer message that echoes command."
+          (let ((emacspeak-speak-messages nil))
+            ad-do-it
+            (emacspeak-auditory-icon 'select-object)
+            ad-return-value))))
 ;;}}}
 ;;{{{ Advise interactive commands:
 
 ;;}}}
 (provide  'emacspeak-gud)
-;;{{{  emacs local variables 
+;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; folded-file: t
 ;;; byte-compile-dynamic: t
-;;; end: 
+;;; end:
 
 ;;}}}
