@@ -1,6 +1,6 @@
 ;;; emacspeak-ocr.el --- ocr Front-end for emacspeak desktop
-;;; $Id: emacspeak-ocr.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-ocr.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for OCR
 ;;; Keywords: Emacspeak, ocr
 ;;{{{  LCD Archive entry:
@@ -8,8 +8,8 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ |
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4448 $ |
 ;;; Location undetermined
 ;;;
 
@@ -62,7 +62,6 @@
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Customization variables
-;;;###autoload
 (defgroup emacspeak-ocr nil
   "Emacspeak front end for scanning and OCR.
 Pre-requisites:
@@ -84,7 +83,9 @@ OCR engine for optical character recognition."
 
 (defcustom emacspeak-ocr-compress-image "tiffcp"
   "Command used to compress the scanned tiff file."
-  :type 'string
+  :type '(choice
+          (const :tag "None" nil)
+          (string :tag "Command"))
   :group 'emacspeak-ocr)
 
 (defcustom emacspeak-ocr-image-extension ".tiff"
@@ -170,7 +171,7 @@ will be placed."
   "Return OCR working buffer."
   (get-buffer-create
    (format  "*%s-ocr*"
-	    (emacspeak-ocr-default-name))))
+            (emacspeak-ocr-default-name))))
 
 (defsubst emacspeak-ocr-get-text-name ()
   "Return name of current text document."
@@ -184,7 +185,7 @@ will be placed."
   (format "%s-p%s%s"
           emacspeak-ocr-document-name
           (1+ emacspeak-ocr-last-page-number)
-	  extension))
+          extension))
 
 (defsubst emacspeak-ocr-get-page-name ()
   "Return name of current page."
@@ -317,6 +318,7 @@ See \\{emacspeak-ocr-mode-map}.
 
 ;;}}}
 ;;{{{ interactive commands
+;;;###autoload
 (defun emacspeak-ocr-customize ()
   "Customize OCR settings."
   (interactive)
@@ -362,6 +364,7 @@ This name will be used as the prefix for naming image and
 text files produced in this scan.")
 
 (make-variable-buffer-local 'emacspeak-ocr-document-name)
+;;;###autoload
 (defun emacspeak-ocr-name-document (name)
   "Name document being scanned in the current OCR buffer.
 Pick a short but meaningful name."
@@ -377,6 +380,7 @@ Pick a short but meaningful name."
   (emacspeak-ocr-update-mode-line)
   (emacspeak-auditory-icon 'select-object)
   (emacspeak-speak-mode-line))
+;;;###autoload
 (defun emacspeak-ocr-scan-image ()
   "Acquire page image."
   (interactive)
@@ -394,25 +398,29 @@ Pick a short but meaningful name."
     (let ((emacspeak-speak-messages nil))
       (shell-command
        (concat
-        (format "%s %s > temp%s;\n"
-                emacspeak-ocr-scan-image
-                emacspeak-ocr-scan-image-options 
-                emacspeak-ocr-image-extension)
-        (format "%s %s  temp%s %s ;\n"
-                emacspeak-ocr-compress-image
-                emacspeak-ocr-compress-image-options
-                emacspeak-ocr-image-extension
-                image-name)
-        (if emacspeak-ocr-keep-uncompressed-image
-            (format "echo \'Uncompressed image not removed.'")
+        (format
+         "%s %s > %s;\n"
+         emacspeak-ocr-scan-image
+         emacspeak-ocr-scan-image-options 
+         (cond
+          ((not emacspeak-ocr-compress-image) image-name)
+          (t (format "temp%s" emacspeak-ocr-image-extension))))
+        (when emacspeak-ocr-compress-image
+          (format "%s %s  temp%s %s ;\n"
+                  emacspeak-ocr-compress-image
+                  emacspeak-ocr-compress-image-options
+                  emacspeak-ocr-image-extension
+                  image-name))
+        (when emacspeak-ocr-keep-uncompressed-image
           (format "rm -f temp%s"
-                  emacspeak-ocr-image-extension)))))
-    (when (interactive-p)
-      (setq emacspeak-ocr-last-page-number
-	    (1+ emacspeak-ocr-last-page-number)))
-    (message "Acquired  image to file %s"
-             image-name)))
+                  emacspeak-ocr-image-extension))))
+      (when (interactive-p)
+        (setq emacspeak-ocr-last-page-number
+              (1+ emacspeak-ocr-last-page-number)))
+      (message "Acquired  image to file %s"
+               image-name))))
 
+;;;###autoload
 (defun emacspeak-ocr-scan-photo (&optional metadata)
   "Scan in a photograph.
 The scanned image is converted to JPEG."
@@ -459,6 +467,7 @@ The scanned image is converted to JPEG."
 
 (defvar emacspeak-ocr-process nil
   "Handle to OCR process.")
+;;;###autoload
 (defun emacspeak-ocr-write-document ()
   "Writes out recognized text from all pages in current document."
   (interactive)
@@ -470,6 +479,7 @@ The scanned image is converted to JPEG."
        (point-max)
        (emacspeak-ocr-get-text-name))
       (emacspeak-auditory-icon 'save-object))))
+;;;###autoload
 (defun emacspeak-ocr-save-current-page ()
   "Writes out recognized text from current page
 to an appropriately named file."
@@ -503,6 +513,7 @@ to an appropriately named file."
   (emacspeak-ocr-save-current-page)
   (emacspeak-ocr-update-mode-line)
   (emacspeak-speak-line))
+;;;###autoload
 (defun emacspeak-ocr-recognize-image ()
   "Run OCR engine on current image.
 Prompts for image file if file corresponding to the expected
@@ -532,15 +543,16 @@ Prompts for image file if file corresponding to the expected
              emacspeak-ocr-last-page-number))
     (setq emacspeak-ocr-process
           (apply 'start-process 
-		 "ocr"
-		 (current-buffer)
-		 emacspeak-ocr-engine
-		 image-name
-		 emacspeak-ocr-engine-options))
+                 "ocr"
+                 (current-buffer)
+                 emacspeak-ocr-engine
+                 image-name
+                 emacspeak-ocr-engine-options))
     (set-process-sentinel emacspeak-ocr-process
                           'emacspeak-ocr-process-sentinel)
     (message "Launched OCR engine.")))
 
+;;;###autoload
 (defun emacspeak-ocr-scan-and-recognize ()
   "Scan in a page and run OCR engine on it.
 Use this command once you've verified that the separate
@@ -550,6 +562,7 @@ correctly by themselves."
   (emacspeak-ocr-scan-image)
   (emacspeak-ocr-recognize-image))
 
+;;;###autoload
 (defun emacspeak-ocr-open-working-directory ()
   "Launch dired on OCR working directory."
   (interactive)
@@ -558,6 +571,7 @@ correctly by themselves."
    (dired-noselect emacspeak-ocr-working-directory))
   (emacspeak-auditory-icon 'open-object)
   (emacspeak-speak-mode-line))
+;;;###autoload
 (defun emacspeak-ocr-forward-page (&optional count-ignored)
   "Like forward page, but tracks page number of current document."
   (interactive "p")
@@ -580,6 +594,7 @@ correctly by themselves."
       (emacspeak-ocr-update-mode-line)
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'large-movement))))
+;;;###autoload
 (defun emacspeak-ocr-backward-page (&optional count-ignored)
   "Like backward page, but tracks page number of current document."
   (interactive "p")
@@ -612,6 +627,7 @@ correctly by themselves."
   (emacspeak-auditory-icon 'large-movement)
   (emacspeak-speak-line)
   )
+;;;###autoload
 (defun emacspeak-ocr-page ()
   "Move to specified page."
   (interactive )
@@ -631,6 +647,7 @@ correctly by themselves."
       (message "Not that many pages in document."))
      (t 
       (emacspeak-ocr-goto-page page)))))
+;;;###autoload
 (defun emacspeak-ocr-read-current-page ()
   "Speaks current page."
   (interactive)
@@ -650,6 +667,7 @@ correctly by themselves."
        (aref emacspeak-ocr-page-positions
              (1+ emacspeak-ocr-current-page-number))))))
 
+;;;###autoload
 (defun emacspeak-ocr-set-scan-image-options  (setting)
   "Interactively update scan image options.
 Prompts with current setting in the minibuffer.
@@ -662,6 +680,7 @@ Setting persists for current Emacs session."
   (declare (special emacspeak-ocr-scan-image-options))
   (setq emacspeak-ocr-scan-image-options setting))
 
+;;;###autoload
 (defun emacspeak-ocr-set-compress-image-options  (setting)
   "Interactively update  image compression options.
 Prompts with current setting in the minibuffer.
