@@ -1,6 +1,6 @@
 ;;; emacspeak-pronounce.el --- Implements Emacspeak pronunciation dictionaries
-;;; $Id: emacspeak-pronounce.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-pronounce.el 5261 2007-09-07 10:25:25Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description: Emacspeak pronunciation dictionaries
 ;;; Keywords:emacspeak, audio interface to emacs customized pronunciation
 ;;{{{  LCD Archive entry:
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ |
+;;; $Date: 2007-09-07 03:25:25 -0700 (Fri, 07 Sep 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman 
 ;;; All Rights Reserved.
 ;;;
@@ -65,7 +65,8 @@
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'custom)
 (eval-when-compile (require 'wid-edit)
-		   (require 'emacspeak-personality))
+                   (require 'calendar)
+                   (require 'emacspeak-personality))
 (require 'voice-setup)
 (require 'thingatpt)
 (eval-when (compile)
@@ -101,22 +102,24 @@ Values are alists containing string.pronunciation pairs.")
   (when (stringp key)
     (setq key (intern key )))
   (gethash key emacspeak-pronounce-dictionaries))
-;;;###autoload
 (defun emacspeak-pronounce-add-dictionary-entry  (key string pronunciation)
   "Add dictionary entry.
 This adds pronunciation pair
 STRING.PRONUNCIATION to the   dictionary.
 Argument KEY specifies a dictionary key e.g. directory, mode etc."
   (declare (special emacspeak-pronounce-dictionaries ))
-  (let ((dict  (emacspeak-pronounce-get-dictionary key)))
+  (let* ((dict  (emacspeak-pronounce-get-dictionary key))
+	 (entry (and dict (assoc string dict))))
     (cond
-     (dict
-      (setf dict
-            (cons (cons string pronunciation) dict))
+     ((and dict entry)
+      (setcdr entry pronunciation))
+     (dict 
+      (setf dict (cons (cons string pronunciation) dict))
       (emacspeak-pronounce-set-dictionary key dict ))
-     (t (emacspeak-pronounce-set-dictionary key
-                                            (list (cons string
-                                                        pronunciation)))))))
+     (t
+      (emacspeak-pronounce-set-dictionary key
+					  (list (cons string pronunciation)))))))
+
 (defun emacspeak-pronounce-remove-buffer-local-dictionary-entry (string)
   "Remove pronunciation entry."
   (when (and (boundp 'emacspeak-pronounce-pronunciation-table)
@@ -143,7 +146,7 @@ Arguments STRING and PRONUNCIATION specify what is being defined."
               emacspeak-pronounce-pronunciation-table)
   (when (interactive-p)
     (message "Added  local pronunciation in buffer %s"
-	     (buffer-name))))
+             (buffer-name))))
 
 ;;}}}
 ;;{{{ setting up inheritance relations
@@ -152,7 +155,6 @@ Arguments STRING and PRONUNCIATION specify what is being defined."
 ;;; parent stored as a property on child symbol.
 ;;; when dictionary composed for a buffer, inherited dictionaries are
 ;;; also looked up.
-;;;###autoload
 (defun emacspeak-pronounce-add-super  (parent child)
   "Make CHILD inherit PARENT's pronunciations."
   (let ((orig (get child 'emacspeak-pronounce-supers)))
@@ -249,70 +251,6 @@ This is the personality used when speaking  things that have a pronunciation
 applied."
   :group 'emacspeak-pronounce
   :type (voice-setup-custom-menu))
-;;;###autoload
-(defsubst emacspeak-pronounce-apply-pronunciations (pronunciation-table )
-  "Applies pronunciations specified in pronunciation table to current buffer.
-Modifies text and point in buffer."
-  (declare (special emacspeak-pronounce-pronunciation-personality))
-  (let ((words
-         (sort 
-          (loop for  key  being the hash-keys  of pronunciation-table collect key)
-          #'(lambda (a b ) 
-              (> (length  a) (length  b))))))
-    (loop for key in words 
-          do
-          (let ((word  key)
-                (pronunciation (gethash  key pronunciation-table))
-                (pp nil)
-                (personality nil))
-            (when word 
-	      (goto-char (point-min))
-	      (cond
-	       ((stringp pronunciation)
-		(while (search-forward  word nil t)
-		  (setq personality (get-text-property (point) 'personality))
-		  (replace-match  pronunciation t t  )
-		  (put-text-property
-		   (match-beginning 0)
-		   (+ (match-beginning 0) (length pronunciation))
-		   'personality
-		   (apply
-		    'append
-		    (mapcar
-		     #'(lambda (p)
-			 (when p
-			   (if (atom p) (list p) p)))
-		     (list emacspeak-pronounce-pronunciation-personality personality))))))
-	       ((consp pronunciation )
-		(let ((matcher (car pronunciation))
-		      (pronouncer (cdr pronunciation))
-		      (pronunciation ""))
-		  (while (funcall matcher   word nil t)
-		    (setq personality
-			  (get-text-property (point) 'personality))
-		    (setq pronunciation
-			  (save-match-data 
-			    (funcall pronouncer
-				     (buffer-substring 
-				      (match-beginning 0)
-				      (match-end 0)))))
-		    (replace-match pronunciation t t  )
-		    ;; get personality if any from pronunciation
-		    (setq pp
-			  (get-text-property (match-beginning 0) 'personality))
-		    (put-text-property
-		     (match-beginning 0)
-		     (+ (match-beginning 0) (length pronunciation))
-		     'personality
-		     (apply 'append
-			    (mapcar
-			     #'(lambda (p)
-				 (when p
-				   (if (atom p) (list p) p)))
-			     (list
-			      emacspeak-pronounce-pronunciation-personality
-			      personality pp)))))))
-	       (t nil)))))))
 
 ;;}}}
 ;;{{{  loading, clearing  and saving dictionaries
@@ -337,11 +275,11 @@ Modifies text and point in buffer."
   (declare (special emacspeak-pronounce-dictionaries))
   (let* (
          (filename (read-file-name
-		    "Save pronunciation dictionaries to file: "
-		    emacspeak-resource-directory
+                    "Save pronunciation dictionaries to file: "
+                    emacspeak-resource-directory
                     nil nil 
-		    (file-name-nondirectory emacspeak-pronounce-dictionaries-file )))
-	 (buffer nil ))
+                    (file-name-nondirectory emacspeak-pronounce-dictionaries-file )))
+         (buffer nil ))
     (setq buffer (find-file-noselect filename))
     (save-excursion
       (set-buffer buffer)
@@ -355,7 +293,6 @@ Modifies text and point in buffer."
                      (emacspeak-pronounce-get-dictionary key ))))
       (save-buffer))))
 
-;;;###autoload
 (defvar emacspeak-pronounce-dictionaries-loaded nil
   "Indicates if dictionaries already loaded.")
 ;;;###autoload
@@ -399,6 +336,7 @@ Optional argument FILENAME specifies the dictionary file."
   "Point where we left off reading from the buffer containing the term being defined.")
 
 (make-variable-buffer-local ' emacspeak-pronounce-yank-word-point)
+;;;###autoload
 (defsubst emacspeak-pronounce-yank-word ()
   "Yank word at point into minibuffer."
   (interactive)
@@ -438,6 +376,7 @@ Optional argument FILENAME specifies the dictionary file."
          (define-key now-map  "\C-w"'emacspeak-pronounce-yank-word))
        now-map))))
 
+;;;###autoload
 (defun emacspeak-pronounce-define-local-pronunciation (word  pronunciation )
   "Define buffer local pronunciation.
 Argument WORD specifies the word which should be pronounced as specified by PRONUNCIATION."
@@ -459,7 +398,7 @@ Returns a pair of the form (key-type . key)."
           (completing-read
            "Define pronunciation that is specific to: "
            emacspeak-pronounce-pronunciation-keys nil t ) )))
-    (when (interactive-p)		;cleanup minibuffer history
+    (when (interactive-p)               ;cleanup minibuffer history
       (pop minibuffer-history))
     (cond
      ((eq key-type 'buffer)
@@ -485,6 +424,7 @@ Returns a pair of the form (key-type . key)."
      (t (error "Cannot define pronunciations with key type %s" key-type)))
     (cons key-type key)))
 
+;;;###autoload
 (defun emacspeak-pronounce-define-template-pronunciation ()
   "Interactively define template entries in the pronunciation dictionaries.
 Default term to define is delimited by region.
@@ -510,6 +450,7 @@ First loads any persistent dictionaries if not already loaded."
     (when (eq (car key-pair)  'buffer)
       (emacspeak-pronounce-add-buffer-local-dictionary-entry word pronunciation))))
 
+;;;###autoload
 (defun emacspeak-pronounce-define-pronunciation ()
   "Interactively define entries in the pronunciation dictionaries.
 Default term to define is delimited by region.
@@ -534,7 +475,6 @@ First loads any persistent dictionaries if not already loaded."
 
 ;;}}}
 ;;{{{ Turning dictionaries on and off on a per buffer basis
-;;;###autoload
 (defvar emacspeak-pronounce-pronunciation-table nil
   "Variable holding association list of pronunciations for a buffer.
 Becomes automatically buffer local.")
@@ -614,11 +554,11 @@ Activates pronunciation dictionaries if not already active."
 modes.
 See http://oz.uc.edu/~solkode/smileys.html for a full list."
   :link '(url-link :tag "Smileys Dictionary "
-		   "http://oz.uc.edu/~solkode/smileys.html")
+                   "http://oz.uc.edu/~solkode/smileys.html")
   :type '(repeat
-	  (cons :tag "Dictionary Entry"
-		(string :tag "String")
-		(string :tag "Pronunciation")))
+          (cons :tag "Dictionary Entry"
+                (string :tag "String")
+                (string :tag "Pronunciation")))
   :group 'emacspeak-pronounce )
 
 ;;}}}
@@ -626,9 +566,13 @@ See http://oz.uc.edu/~solkode/smileys.html for a full list."
 
 (defcustom emacspeak-pronounce-common-xml-namespace-uri-pronunciations 
   '(
+    ("http://schemas.google.com/g/2005" . " gd ")
+    ("http://www.w3.org/2005/Atom" . " atom ")
     ("http://www.w3.org/1999/02/22-rdf-syntax-ns#" . "RDF Syntax")
     ("http://www.w3.org/2002/06/xhtml2" . " xhtml2 ")
-    ("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul" . "XUL" )
+    ("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"
+     . "XUL" )
+    ("http://www.mozilla.org/xbl" . " xbl ")
     ("http://www.w3.org/2003/XInclude" . "xinclude")
     ("http://www.w3.org/1999/XSL/Transform" . " XSLT ")
     ("http://www.w3.org/2002/xforms" . " XForms ")
@@ -643,14 +587,13 @@ See http://oz.uc.edu/~solkode/smileys.html for a full list."
     )
   "Pronunciations for well known namespace URIs."
   :type '(repeat
-	  (cons :tag "Dictionary Entry"
-		(string :tag "Namespace URI")
-		(string :tag "Pronunciation")))
+          (cons :tag "Dictionary Entry"
+                (string :tag "Namespace URI")
+                (string :tag "Pronunciation")))
   :group 'emacspeak-pronounce )
 
 ;;}}}
 ;;{{{ adding predefined dictionaries to a mode:
-;;;###autoload
 (defun emacspeak-pronounce-augment-pronunciations (mode dictionary)
   "Pushes pronunciations in specified dictionary on to the dictionary
 for the specified mode."
@@ -659,7 +602,7 @@ for the specified mode."
           do
           (unless (assoc (car e)
                          mode-alist)
-	    (push e mode-alist)))
+            (push e mode-alist)))
     (emacspeak-pronounce-set-dictionary mode mode-alist)))
 
 ;;}}}
@@ -710,36 +653,36 @@ pronunciation dictionary for the specified key."
 
 (defun emacspeak-pronounce-edit-generate-callback (field-name)
   "Generate a callback for use in the pronunciation editor widget."
-  (`
-   (lambda (widget &rest ignore)
+  `(lambda (widget &rest ignore)
      (declare (special emacspeak-pronounce-dictionaries))
      (let ((value (widget-value widget)))
        (setf
         (gethash 
-         (quote (, field-name))
+         (quote ,field-name)
          emacspeak-pronounce-dictionaries)
-        value)))))
+        value))))
 
+;;;###autoload
 (defun emacspeak-pronounce-edit-pronunciations (key)
   "Prompt for and launch a pronunciation editor on the
 specified pronunciation dictionary key."
   (interactive
    (list
     (let ((keys
-	   (loop for k being the hash-keys of
-		 emacspeak-pronounce-dictionaries
-		 collect
-		 (symbol-name k))))
+           (loop for k being the hash-keys of
+                 emacspeak-pronounce-dictionaries
+                 collect
+                 (symbol-name k))))
       (completing-read "Edit dictionary: "
-		       (mapcar
-			#'(lambda (k)
-			    (cons k k ))
-			keys)
-		       nil
-		       'REQUIRE-MATCH 
-		       nil
-		       'keys
-		       (car keys))))) 
+                       (mapcar
+                        #'(lambda (k)
+                            (cons k k ))
+                        keys)
+                       nil
+                       'REQUIRE-MATCH 
+                       nil
+                       'keys
+                       (car keys))))) 
   (declare (special emacspeak-pronounce-dictionaries))
   (emacspeak-pronounce-edit-generate-pronunciation-editor
    (intern key)))
@@ -751,6 +694,7 @@ specified pronunciation dictionary key."
   "Dictionary:  Clear Define Edit Load Refresh Save Toggle"
   "Help message listing emacspeak commands.")
 
+;;;###autoload
 (defun emacspeak-pronounce-dispatch ()
   "Provides the user interface front-end to Emacspeak's pronunciation dictionaries."
   (interactive)
