@@ -1,23 +1,23 @@
 ;;; emacspeak-setup.el --- Setup Emacspeak environment --loaded to start Emacspeak
-;;; $Id: emacspeak-setup.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-setup.el 5377 2007-11-23 01:17:25Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  File for setting up and starting Emacspeak
 ;;; Keywords: Emacspeak, Setup, Spoken Output
-;;{{{  LCD Archive entry: 
+;;{{{  LCD Archive entry:
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-11-22 17:17:25 -0800 (Thu, 22 Nov 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved. 
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -44,7 +44,7 @@
 ;;; Code:
 
 ;;}}}
-;;{{{ Required Modules 
+;;{{{ Required Modules
 
 (eval-when-compile (require 'cl))
 (declaim  (optimize  (safety 0) (speed 3)))
@@ -53,13 +53,13 @@
   (require 'emacspeak-preamble))
 
 ;;}}}
-;;{{{  Define locations 
+;;{{{  Define locations
 
 (defvar emacspeak-unibyte t
   "Emacspeak will force emacs to unibyte unless this
 variable is set to nil.
 To use emacspeak with emacs running in multibyte mode, this
-variable should be set to nil *before* 
+variable should be set to nil *before*
 emacspeak is compiled or started.")
 ;;;###autoload
 (defvar emacspeak-directory
@@ -74,6 +74,11 @@ emacspeak is compiled or started.")
   (expand-file-name  "sounds/" emacspeak-directory)
   "Directory containing auditory icons for Emacspeak.")
 ;;;###autoload
+(defvar emacspeak-xslt-directory
+  (expand-file-name "xsl/" emacspeak-directory)
+  "Directory holding XSL transformations.")
+
+;;;###autoload
 (defvar emacspeak-etc-directory
   (expand-file-name  "etc/" emacspeak-directory)
   "Directory containing miscellaneous files  for
@@ -91,61 +96,108 @@ emacspeak is compiled or started.")
 (defvar emacspeak-resource-directory (expand-file-name "~/.emacspeak/")
   "Directory where Emacspeak resource files such as
 pronunciation dictionaries are stored. ")
+;;;###autoload
+(defvar emacspeak-readme-file
+  (expand-file-name "README"
+                    emacspeak-directory)
+  "README file from where we get SVN revision number.")
+
+;;;###autoload
+(defconst emacspeak-version
+  (eval-when-compile
+    (format
+     "26.0 %s"
+     (cond
+      ((file-exists-p emacspeak-readme-file)
+       (let ((buffer (find-file-noselect emacspeak-readme-file))
+             (revision nil))
+         (save-excursion
+           (set-buffer buffer)
+           (goto-char (point-min))
+           (setq revision
+                 (format "Revision %s"
+                         (or
+                          (nth 2 (split-string
+                                  (buffer-substring-no-properties
+                                   (line-beginning-position)
+                                   (line-end-position))))
+                          "unknown"))))
+         (kill-buffer buffer)
+         revision))
+      (t ""))))
+  "Version number for Emacspeak.")
+
+;;;###autoload
+(defconst emacspeak-codename
+  "FastDog"
+  "Code name of present release.")
 
 ;;}}}
-;;{{{ speec rate 
+;;{{{ speech rate
 
 (defcustom outloud-default-speech-rate 50
   "Default speech rate for outloud."
   :group 'tts
   :type 'integer)
 
+(defcustom multispeech-default-speech-rate 225
+  "Default speech rate for multispeech."
+  :group 'tts
+  :type 'integer)
+
 (defcustom dectalk-default-speech-rate 225
   "*Default speech rate at which TTS is started. "
   :group 'tts
   :type 'integer)
 
+(defcustom espeak-default-speech-rate 170
+  "Default speech rate for eSpeak."
+  :group 'tts
+  :type 'integer)
+
 (defvar tts-default-speech-rate dectalk-default-speech-rate
   "Setup on a per engine basis.")
 
 ;;}}}
 ;;{{{ Hooks
 
-(unless (featurep 'emacspeak)
-  (setq load-path
-        (cons emacspeak-lisp-directory 
-              load-path )))
-(defconst  emacspeak-xemacs-p
-  (when
-      (or (boundp 'running-xemacs)
-	  (string-match "Lucid\\|XEmacs" emacs-version))
-    t)
-  "T if we are running under XEmacs.")
+(add-to-list 'load-path emacspeak-lisp-directory )
+(add-to-list 'load-path (expand-file-name "g-client" emacspeak-lisp-directory ))
 
 (load-library "emacspeak")
+
 (defvar dtk-startup-hook nil)
 (defun emacspeak-tts-startup-hook ()
   "Default hook function run after TTS is started."
+  (tts-configure-synthesis-setup)
   (dtk-set-rate tts-default-speech-rate t)
   (dtk-interp-sync))
 
-(add-hook 'dtk-startup-hook 
+(add-hook 'dtk-startup-hook
           'emacspeak-tts-startup-hook)
 
 (defvar emacspeak-startup-hook nil)
-
+(defun emacspeak-setup-header-line ()
+  "Set up Emacspeak to show a default header line."
+  (declare (special emacspeak-use-header-line
+                    default-header-line-format
+                    emacspeak-default-header-line-format))
+  (when emacspeak-use-header-line
+    (setq default-header-line-format
+          emacspeak-default-header-line-format)))
+(add-hook 'emacspeak-startup-hook 'emacspeak-setup-header-line)
+          
 ;;; Use (add-hook 'emacspeak-startup-hook ...)
-;;; to add your personal settings. 
+;;; to add your personal settings.
 
 ;;}}}
-
 (emacspeak)
 (provide 'emacspeak-setup)
-;;{{{  emacs local variables 
+;;{{{  emacs local variables
 
 ;;; local variables:
 ;;; major-mode: emacs-lisp-mode
 ;;; folded-file: t
-;;; end: 
+;;; end:
 
 ;;}}}
