@@ -1,6 +1,6 @@
 ;;; emacspeak-tapestry.el --- Speak information about current layout of windows
-;;; $Id: emacspeak-tapestry.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-tapestry.el 5246 2007-09-01 22:30:13Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak module to speak window tapestries
 ;;; Keywords:emacspeak, audio interface to emacs tapestry
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -68,36 +68,36 @@ displayed buffers."
                        'personality  voice-annotate
                        description)
     (setq windows 
-	  (cond
-	   (details 
-	    (loop for buffer in buffer-map
-		  and window in window-list
-		  collect
-		  (let ((w (format "%s "  (second buffer)))
-			(corners  (window-edges window))
-			(tl nil )
-			(br nil))
-		    (put-text-property 0 (length w)
-				       'personality
-				       voice-animate w)
-		    (setq tl
-			  (format  " %d %d "
-				   (first corners) (second corners))
-			  br  (format " %d %d "
-				      (third corners) (fourth corners)))
-		    (put-text-property 0 (length tl)
-				       'personality voice-bolden tl)
-		    (put-text-property 0 (length br)
-				       'personality voice-bolden br)
-		    (concat w
-			    " with top left "
-			    tl
-			    " and bottom right "
-			    br))))
-	   (t
-	    (loop for buffer in buffer-map
-		  collect
-		  (second buffer)))))
+          (cond
+           (details 
+            (loop for buffer in buffer-map
+                  and window in window-list
+                  collect
+                  (let ((w (format "%s "  (second buffer)))
+                        (corners  (window-edges window))
+                        (tl nil )
+                        (br nil))
+                    (put-text-property 0 (length w)
+                                       'personality
+                                       voice-animate w)
+                    (setq tl
+                          (format  " %d %d "
+                                   (first corners) (second corners))
+                          br  (format " %d %d "
+                                      (third corners) (fourth corners)))
+                    (put-text-property 0 (length tl)
+                                       'personality voice-bolden tl)
+                    (put-text-property 0 (length br)
+                                       'personality voice-bolden br)
+                    (concat w
+                            " with top left "
+                            tl
+                            " and bottom right "
+                            br))))
+           (t
+            (loop for buffer in buffer-map
+                  collect
+                  (second buffer)))))
     (tts-with-punctuations 'all
                            (dtk-speak
                             (concat description
@@ -117,10 +117,11 @@ but quickly switch to a window by name."
      "Select window: "
      (mapcar 
       #'(lambda (w)
-	  (list (buffer-name (window-buffer w))))
+          (list (buffer-name (window-buffer w))))
       (tapestry-window-list))
      nil 'must-match)))
-  (pop-to-buffer buffer-name))
+  (pop-to-buffer buffer-name)
+  (emacspeak-speak-line))
 
 ;;}}}
 (provide  'emacspeak-tapestry)
