@@ -1,24 +1,24 @@
 ;;; emacspeak-vm.el --- Speech enable VM -- A powerful mail agent (and the one I use)
-;;; $Id: emacspeak-vm.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-vm.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enhance vm
 ;;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
-;;{{{  LCD Archive entry: 
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4557 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved. 
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -89,15 +89,13 @@ Note that some badly formed mime messages  cause trouble."
         (dtk-stop-immediately t))
     (emacspeak-kill-buffer-carefully "*Completions*")
     ad-do-it
-    (let ((completions-buffer (get-buffer "*Completions*")))
-      (if (> (point) prior)
-          (dtk-speak (buffer-substring prior (point )))
-        (when (and completions-buffer
-                   (window-live-p (get-buffer-window completions-buffer )))
-          (save-excursion
-            (set-buffer completions-buffer )
-            (emacspeak-prepare-completions-buffer)
-            (dtk-speak (buffer-string ))))))
+    (if (> (point) prior)
+        (tts-with-punctuations
+         'all
+         (if (> (length (emacspeak-get-minibuffer-contents)) 0)
+             (dtk-speak (emacspeak-get-minibuffer-contents))
+           (emacspeak-speak-line)))
+      (emacspeak-speak-completions-if-available))
     ad-return-value))
 
 (defadvice vm-minibuffer-complete-word-and-exit (around emacspeak pre act)
@@ -106,19 +104,18 @@ Note that some badly formed mime messages  cause trouble."
         (dtk-stop-immediately t))
     (emacspeak-kill-buffer-carefully "*Completions*")
     ad-do-it
-    (let ((completions-buffer (get-buffer "*Completions*")))
-      (if (> (point) prior)
-          (dtk-speak (buffer-substring prior (point )))
-        (when (and completions-buffer
-                   (window-live-p (get-buffer-window completions-buffer )))
-          (save-excursion
-            (set-buffer completions-buffer )
-            (emacspeak-prepare-completions-buffer)
-            (dtk-speak (buffer-string ))))))
+    (if (> (point) prior)
+        (tts-with-punctuations
+         'all
+         (if (> (length (emacspeak-get-minibuffer-contents)) 0)
+             (dtk-speak (emacspeak-get-minibuffer-contents))
+           (emacspeak-speak-line)))
+      (emacspeak-speak-completions-if-available))
     ad-return-value))
 
 ;;}}}
 ;;{{{  Helper functions:
+
 (defvar emacspeak-vm-user-full-name (user-full-name)
   "Full name of user using this session")
 
@@ -137,19 +134,36 @@ Note that some badly formed mime messages  cause trouble."
             (to (vm-to-of message ))
             (header nil))
       (while (not header)
-	(setq header 
-	      (case
-		  (read-char "f From s Subject t To")
-		(?s subject)
-		(?f from)
-		(?t to))))
+        (setq header
+              (case
+                  (read-char "f From s Subject t To")
+                (?s subject)
+                (?f from)
+                (?t to))))
       (kill-new header)
       (message header)))
    (t (error "No current message." ))))
+(defcustom emacspeak-vm-headers-strip-octals t
+  "Specify whether non-ascii chars should be stripped when
+  speaking email headers."
+  :type 'boolean
+  :group 'emacspeak-vm)
+
+(defun emacspeak-vm-speak-message ()
+  "Move point to the message body."
+  (interactive)
+  (goto-char (point-min))
+  (search-forward  (format "%c%c" 10 10) nil)
+  (condition-case nil
+      (emacspeak-hide-all-blocks-in-buffer)
+    (error nil))
+  (emacspeak-auditory-icon 'large-movement)
+  (emacspeak-speak-rest-of-buffer))
 
 (defun emacspeak-vm-summarize-message ()
   "Summarize the current vm message. "
   (declare (special vm-message-pointer
+                    emacspeak-vm-headers-strip-octals
                     emacspeak-vm-user-full-name emacspeak-vm-user-login-name))
   (when vm-message-pointer
     (dtk-stop)
@@ -175,13 +189,13 @@ Note that some badly formed mime messages  cause trouble."
                 (if (and to (< (length to) 80))
                     (format "to %s" to) "")
                 (if lines (format "%s lines" lines) ""))))
-      (cond 
+      (cond
        ((and self-p
-             (= 0 self-p)                    ) ;mail to me and others 
+             (= 0 self-p)                    ) ;mail to me and others
         (emacspeak-auditory-icon 'item))
-       (self-p				;mail to others including me
+       (self-p                          ;mail to others including me
         (emacspeak-auditory-icon 'mark-object))
-       (t			     ;got it because of a mailing list
+       (t                            ;got it because of a mailing list
         (emacspeak-auditory-icon 'select-object ))))))
 
 (defun emacspeak-vm-speak-labels ()
@@ -211,7 +225,7 @@ Note that some badly formed mime messages  cause trouble."
        (format "Message %s of %s from virtual folder %s"
                vm-ml-message-number vm-ml-highest-message-number
                (car vm-virtual-folder-definition))))
-     (t (dtk-speak 
+     (t (dtk-speak
          (format "Message %s of %s,    %s %s %s  %s"
                  vm-ml-message-number vm-ml-highest-message-number
                  (if vm-ml-message-new "new" "")
@@ -228,8 +242,6 @@ Note that some badly formed mime messages  cause trouble."
                                     value))
                                  (t "")))))
                   (cdr vm-ml-message-attributes-alist)   " ")))))))
-    
-    
 
 ;;}}}
 ;;{{{  Moving between messages
@@ -283,10 +295,8 @@ Then speak the screenful. "
 (declaim (special vm-mode-map))
 (define-key vm-mode-map "\M-\C-m" 'widget-button-press)
 (define-key vm-mode-map "y" 'emacspeak-vm-yank-header)
-(define-key vm-mode-map "\M-\t"
-  'emacspeak-vm-next-button)
-(define-key vm-mode-map  "j"
-  'emacspeak-hide-or-expose-all-blocks)
+(define-key vm-mode-map "\M-\t" 'emacspeak-vm-next-button)
+(define-key vm-mode-map  "j" 'emacspeak-hide-or-expose-all-blocks)
 (define-key vm-mode-map  "\M-g" 'vm-goto-message)
 (define-key vm-mode-map "J" 'vm-discard-cached-data)
 (define-key vm-mode-map "." 'emacspeak-vm-browse-message)
@@ -308,8 +318,8 @@ Then speak the screenful. "
 (defadvice vm-kill-subject (after emacspeak pre act)
   "Provide auditory feedback. "
   (when (interactive-p)
-    (dtk-speak "Killed this thread ")
-    (emacspeak-auditory-icon 'delete-object)))
+    (emacspeak-auditory-icon 'delete-object)
+    (call-interactively 'vm-next-message)))
 
 ;;}}}
 ;;{{{  Sending mail:
@@ -334,7 +344,7 @@ Then speak the screenful. "
   (when (interactive-p)
     (message "Folluwing up")
     (emacspeak-speak-mode-line)))
-      
+
 (defadvice vm-reply-include-text (after emacspeak pre act)
   "Provide aural feedback."
   (when (interactive-p)
@@ -369,7 +379,9 @@ Then speak the screenful. "
 (defadvice vm-quit (after emacspeak pre act )
   "Provide an auditory icon if requested"
   (when (interactive-p)
-    (emacspeak-auditory-icon 'close-object)))
+    (emacspeak-auditory-icon 'close-object)
+    (message "%s"
+             (emacspeak-speak-mode-line))))
 
 ;;}}}
 ;;{{{ catching up on folders
@@ -390,8 +402,9 @@ Then speak the screenful. "
                    global-map
                    emacspeak-prefix
                    emacspeak-keymap))
-(define-key vm-mode-map "C" 'emacspeak-vm-catch-up-all-messages)
+(define-key vm-mode-map "\M-c" 'emacspeak-vm-catch-up-all-messages)
 (define-key vm-mode-map "\M-j" 'emacspeak-vm-locate-subject-line)
+(define-key vm-mode-map "," 'emacspeak-vm-speak-message)
 (define-key vm-mode-map "\M-l" 'emacspeak-vm-speak-labels)
 (define-key vm-mode-map
   (concat emacspeak-prefix "m")
@@ -460,44 +473,54 @@ Leave point at front of decoded attachment."
     ad-do-it))
 
 ;;}}}
-;;{{{ advice password prompt 
+;;{{{ advice password prompt
 
 (defadvice vm-read-password(before emacspeak pre act comp)
   "Speak the prompt"
   (let ((prompt (ad-get-arg 0))
         (confirm (ad-get-arg 1)))
     (emacspeak-auditory-icon 'open-object)
-    (dtk-speak 
+    (dtk-speak
      (format "%s %s"
              prompt
              (if confirm "Confirm by retyping" "")))))
 ;;}}}
 ;;{{{ setup presentation buffer correctly
+
 (add-hook 'vm-presentation-mode-hook
-          (function
-           (lambda nil
-             (emacspeak-pronounce-refresh-pronunciations))))
+          #'(lambda nil
+              (emacspeak-pronounce-refresh-pronunciations)))
 (declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
-(loop for hook in 
+(loop for hook in
       (list 'mail-mode-hook
             'vm-presentation-mode-hook)
-      do 
+      do
       (add-hook hook 'emacspeak-pronounce-refresh-pronunciations
                 'append ))
 
-(loop for mode in 
-      '(vm-presentation-mode 
+(loop for mode in
+      '(vm-presentation-mode
         mail-mode)
-      do 
+      do
       (emacspeak-pronounce-augment-pronunciations mode
                                                   emacspeak-pronounce-internet-smileys-pronunciations)
+      (emacspeak-pronounce-add-dictionary-entry mode
+                                                emacspeak-speak-embedded-url-pattern
+                                                (cons 're-search-forward
+                                                      #'(lambda
+                                                          (url) "
+      Link ")))
+      (emacspeak-pronounce-add-dictionary-entry mode
+                                                emacspeak-speak-rfc-3339-datetime-pattern
+                                                (cons 're-search-forward
+                                                      'emacspeak-speak-decode-rfc-3339-datetime))
       (emacspeak-pronounce-add-dictionary-entry mode
                                                 emacspeak-speak-iso-datetime-pattern
                                                 (cons 're-search-forward
-                                                      'emacspeak-speak-decode-iso-datetime)))          
+                                                      'emacspeak-speak-decode-iso-datetime)))
 
 ;;}}}
-;;{{{ advice button motion 
+;;{{{ advice button motion
 (defadvice vm-next-button (after emacspeak pre act comp)
   "Provide auditory feedback"
   (when (interactive-p)
@@ -505,48 +528,48 @@ Leave point at front of decoded attachment."
     (emacspeak-speak-text-range  'w3-hyperlink-info)))
 
 ;;}}}
-;;{{{  misc 
+;;{{{  misc
 
 (defadvice vm-count-messages-in-file (around emacspeak-fix pre act comp)
   (ad-set-arg 1 'quiet)
   ad-do-it)
 
 ;;}}}
-;;{{{  button motion in vm 
+;;{{{  button motion in vm
 
 (defun emacspeak-vm-next-button (n)
   "Move point to N buttons forward.
 If N is negative, move backward instead."
   (interactive "p")
   (let ((function (if (< n 0) 'previous-single-property-change
-		    'next-single-property-change))
-	(inhibit-point-motion-hooks t)
-	(backward (< n 0))
-	(limit (if (< n 0) (point-min) (point-max))))
+                    'next-single-property-change))
+        (inhibit-point-motion-hooks t)
+        (backward (< n 0))
+        (limit (if (< n 0) (point-min) (point-max))))
     (setq n (abs n))
     (while (and (not (= limit (point)))
-		(> n 0))
+                (> n 0))
       ;; Skip past the current button.
       (when (get-text-property (point) 'w3-hyperlink-info)
-	(goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
+        (goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
       ;; Go to the next (or previous) button.
       (goto-char (funcall function (point) 'w3-hyperlink-info nil limit))
       ;; Put point at the start of the button.
       (when (and backward (not (get-text-property (point) 'w3-hyperlink-info)))
-	(goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
+        (goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
       ;; Skip past intangible buttons.
       (when (get-text-property (point) 'intangible)
-	(incf n))
+        (incf n))
       (decf n))
     (unless (zerop n)
       (message  "No more buttons"))
     n))
 
 ;;}}}
-;;{{{ saving mime attachment under point 
+;;{{{ saving mime attachment under point
 
 ;;}}}
-;;{{{ configure and customize vm 
+;;{{{ configure and customize vm
 
 ;;; This is how I customize VM
 
@@ -560,12 +583,12 @@ If N is negative, move backward instead."
 Emacspeak."
   (declare (special
             vm-mime-charset-converter-alist
-            vm-mime-default-face-charsets 
-            vm-frame-per-folder 
-            vm-frame-per-composition 
-            vm-frame-per-edit 
-            vm-frame-per-help 
-            vm-frame-per-summary 
+            vm-mime-default-face-charsets
+            vm-frame-per-folder
+            vm-frame-per-composition
+            vm-frame-per-edit
+            vm-frame-per-help
+            vm-frame-per-summary
             vm-index-file-suffix
             vm-primary-inbox
             vm-folder-directory
@@ -579,16 +602,16 @@ Emacspeak."
             vm-move-after-deleting
             emacspeak-vm-voice-lock-messages))
   (setq vm-mime-charset-converter-alist
-	'(
-	  ("utf-8" "iso-8859-1" "iconv -f utf-8 -t iso-8859-1")
-	  )
-	)
+        '(
+          ("utf-8" "iso-8859-1" "iconv -f utf-8 -t iso-8859-1")
+          )
+        )
   (setq vm-mime-default-face-charsets t)
   (setq vm-frame-per-folder nil
-	vm-frame-per-composition nil
-	vm-frame-per-edit nil
-	vm-frame-per-help nil
-	vm-frame-per-summary nil)
+        vm-frame-per-composition nil
+        vm-frame-per-edit nil
+        vm-frame-per-help nil
+        vm-frame-per-summary nil)
 
   (setq vm-index-file-suffix ".idx"
         vm-primary-inbox "~/mbox"
@@ -603,7 +626,7 @@ Emacspeak."
         vm-move-after-deleting nil
         emacspeak-vm-voice-lock-messages t)
   t)
-  
+
 (when emacspeak-vm-use-raman-settings
   (emacspeak-vm-use-raman-settings))
 
@@ -655,26 +678,26 @@ text using wvText."
        #'(lambda  (i)
            (string-equal (car i) (car convertor)))
        vm-mime-type-converter-alist)
-    (push   convertor 
+    (push   convertor
             vm-mime-type-converter-alist)))
 
 (defun emacspeak-vm-customize-mime-settings ()
   "Customize VM mime settings."
   (declare (special vm-preview-lines
-		    vm-infer-mime-types
-		    vm-mime-decode-for-preview
-		    vm-auto-decode-mime-messages
-		    vm-auto-displayed-mime-content-type-exceptions
-		    vm-mime-attachment-save-directory
-		    vm-mime-base64-encoder-program
-		    vm-mime-base64-decoder-program
-		    vm-mime-attachment-auto-type-alist
-		    vm-mime-type-converter-alist
-		    emacspeak-vm-pdf2text
-		    emacspeak-vm-ppt2html
-		    emacspeak-vm-xls2html
-		    emacspeak-vm-doc2text
-		    emacspeak-vm-cal2text))
+                    vm-infer-mime-types
+                    vm-mime-decode-for-preview
+                    vm-auto-decode-mime-messages
+                    vm-auto-displayed-mime-content-type-exceptions
+                    vm-mime-attachment-save-directory
+                    vm-mime-base64-encoder-program
+                    vm-mime-base64-decoder-program
+                    vm-mime-attachment-auto-type-alist
+                    vm-mime-type-converter-alist
+                    emacspeak-vm-pdf2text
+                    emacspeak-vm-ppt2html
+                    emacspeak-vm-xls2html
+                    emacspeak-vm-doc2text
+                    emacspeak-vm-cal2text))
   (emacspeak-vm-add-mime-convertor
    (list "text/calendar" "text/plain" emacspeak-vm-cal2text))
   (emacspeak-vm-add-mime-convertor
@@ -696,7 +719,6 @@ text using wvText."
         vm-mime-base64-encoder-program "base64-encode"
         vm-mime-base64-decoder-program "base64-decode")
   t)
-   
 
 (when emacspeak-vm-customize-mime-settings
   (emacspeak-vm-customize-mime-settings))
@@ -708,6 +730,6 @@ text using wvText."
 ;;; local variables:
 ;;; folded-file: t
 ;;; byte-compile-dynamic: t
-;;; end: 
+;;; end:
 
 ;;}}}
