@@ -1,6 +1,6 @@
 ;;; emacspeak-widget.el --- Speech enable Emacs' native GUI widget library
-;;; $Id: emacspeak-widget.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-widget.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak extensions to widgets
 ;;; Keywords:emacspeak, audio interface to emacs customized widgets
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -65,46 +65,22 @@
 (defgroup emacspeak-widget nil
   "Widgets on the Emacspeak Desktop."
   :group 'emacspeak
-  :group 'widgets
-  :prefix "emacspeak-widget-")
-(def-voice-font  emacspeak-widget-field-personality  voice-smoothen
-  'widget-field-face
-  "Personality for edit fields"
-  :group 'emacspeak-widget
-  :type 'symbol)
+  :group 'widget
+  :prefix "emacspeak-widget")
 
-(def-voice-font  emacspeak-widget-single-line-field-personality  voice-smoothen
-  'widget-single-line-field-face
-  "Personality for edit fields"
-  :group 'emacspeak-widget
-  :type 'symbol)
-
-(defcustom emacspeak-widget-value-personality voice-animate
-  "Personality for values"
-  :group 'emacspeak-widget)
-
-(def-voice-font emacspeak-widget-button-personality voice-bolden
-  'widget-button-face
-  "Personality for buttons"
-  :group 'emacspeak-widget)
-
-(def-voice-font emacspeak-widget-documentation-personality
-  voice-smoothen-extra
-  'widget-documentation-face
-  "Personality for documentation"
-  :group 'emacspeak-widget)
-
-(def-voice-font emacspeak-widget-inactive-personality  voice-lighten
-  'widget-inactive-face
-  "Personality for inactive fields"
-  :group 'emacspeak-widget)
+(voice-setup-add-map
+ '(
+   (widget-field voice-smoothen)
+   (widget-single-line-field voice-smoothen)
+   (widget-button voice-bolden)
+   (widget-button-pressed voice-bolden-extra)
+   (widget-documentation voice-smoothen-extra)
+   (widget-inactive voice-lighten)
+   ))
 
 (declaim (special widget-menu-minibuffer-flag))
 (setq  widget-menu-minibuffer-flag t)
 
-(define-widget-keywords :emacspeak-help
-  :caption)
-
 ;;}}}
 ;;{{{  helpers 
 
@@ -115,10 +91,10 @@ Returns a string with appropriate personality."
         (type   (widget-type w))
         (tag (widget-get w :tag)))
     (setq tag     
-	  (format " %s "
-		  (or tag type)))
+          (format " %s "
+                  (or tag type)))
     (put-text-property 0 (length tag)
-		       'personality emacspeak-widget-button-personality tag)
+                       'personality 'emacspeak-widget-button-personality tag)
     tag))
 
 (defsubst emacspeak-widget-help-echo (w)
@@ -200,7 +176,7 @@ Returns a string with appropriate personality."
            (t (prin1-to-string v 'no-escape)))))
     (when  value
       (put-text-property 0 (length value)
-                         'personality emacspeak-widget-value-personality value))
+                         'personality voice-bolden value))
     (concat label
             help-echo
             value)))
@@ -378,7 +354,7 @@ Returns a string with appropriate personality."
   (let ((value (widget-get widget :value))
         (tag (widget-get widget :tag)))
     (format "Commentary  link   %s %s"
-	    (or tag "")
+            (or tag "")
             value)))
 
 (widget-put (get 'emacs-commentary-link 'widget-type)
@@ -430,7 +406,7 @@ Returns a string with appropriate personality."
                       (value (prin1-to-string value))
                       (t " no items  "))))
     (put-text-property 0  (length selections)
-                       'personality emacspeak-widget-value-personality selections)
+                       'personality voice-bolden selections)
     (concat label
             " has "
             selections 
@@ -509,10 +485,10 @@ Returns a string with appropriate personality."
           (cond
            (choice (widget-get choice :tag))
            (t (if value 
-		  (prin1-to-string value)
-		" no item ")))))
+                  (prin1-to-string value)
+                " no item ")))))
     (put-text-property 0  (length selected)
-                       'personality emacspeak-widget-value-personality selected)
+                       'personality voice-bolden selected)
     (concat label
             " is "
             selected)))
@@ -531,7 +507,7 @@ Returns a string with appropriate personality."
         (help-echo (emacspeak-widget-help-echo widget)))
     (when value
       (put-text-property 0 (length value)
-                         'personality emacspeak-widget-value-personality value))
+                         'personality voice-bolden value))
     (concat label
             help-echo
             (or value ""))))
@@ -687,7 +663,7 @@ widget before summarizing."
   (loop for map in
         (list widget-keymap
               widget-field-keymap
-	      widget-text-keymap
+              widget-text-keymap
               )
         do
         (define-key map  emacspeak-prefix 'emacspeak-prefix-command)
