@@ -1,6 +1,6 @@
 ;;; emacspeak-xml-shell.el --- Implements a simple XML browser
-;;; $Id: emacspeak-xml-shell.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-xml-shell.el 5246 2007-09-01 22:30:13Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Contains  xml-shell
 ;;; Keywords: Emacspeak,  Audio Desktop Xml-Shell
 ;;{{{  LCD Archive entry:
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ |
+;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2007, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -55,7 +55,8 @@
 ;;{{{ Customizations
 ;;;###autoload
 (defgroup emacspeak-xml-shell nil
-  "XML browser for the Emacspeak desktop.")
+  "XML browser for the Emacspeak desktop."
+  :group 'emacspeak)
 
 (defcustom emacspeak-xml-shell-command "xmllint"
   "Executable that provides the XML browser shell.
@@ -103,9 +104,9 @@ Interactive XML browser.
                        emacspeak-xml-shell-command
                        nil
                        (append emacspeak-xml-shell-options
-			       (if (string-match ".html?$" system-id)
-				   (list "--html")
-				 nil )
+                               (if (string-match ".html?$" system-id)
+                                   (list "--html")
+                                 nil )
                                (list system-id)))))
     (save-excursion
       (set-buffer buffer)
@@ -201,11 +202,10 @@ content.
 Post-processor accepts a region of text to process specified by start
 and end."
   (declare (special emacspeak-xml-shell-display-buffer))
-  (`
-   (lambda (process output)
-     (let ((stream  (, accumulate))
-           (processor (function (, post-processor)))
-           (done  (, terminator)))
+  `(lambda (process output)
+     (let ((stream  ,accumulate)
+           (processor (function ,post-processor))
+           (done  ,terminator))
        (save-excursion
          (set-buffer stream)
          (goto-char (point-max))
@@ -225,7 +225,7 @@ and end."
              (set-buffer (process-buffer process))
              (goto-char (point-max))
              (comint-send-input)))
-          (t (insert output))))))))
+          (t (insert output)))))))
 
 (defvar emacspeak-xml-shell-cat
   (cond
@@ -274,7 +274,7 @@ HTML head if none found."
   (goto-char (point-min))
   (let ((head   (search-forward "<head>" nil t)))
     (or head
-	(insert "<head>\n"))
+        (insert "<head>\n"))
     (insert
      (format "<base href=\"%s\">\n" base))
     (or head (insert "</head>\n"))))
@@ -292,7 +292,7 @@ HTML head if none found."
     (goto-char (point-min))
     (while (search-forward "-------" nil t)
       (replace-match "<br>")))
-  (emacspeak-w3-preview-this-buffer)
+  (browse-url-of-buffer)
   (setq emacspeak-xml-shell-display-buffer (current-buffer)))
 
 (defun emacspeak-xml-shell-browse-current ()
